@@ -2,7 +2,7 @@
     metadata
     ~~~~~~~~
 
-    Blog metadata extension. The extension extracts and computes metadata 
+    Blog metadata extension. The extension extracts and computes metadata
     associated with blog posts/pages and stores it in the environment.
 
     :copyright: Copyright 2011-2012 by Vlad Riscutia and contributors (see
@@ -10,9 +10,11 @@
     :license: FreeBSD, see LICENSE file
 '''
 import re
-import datetime 
+import datetime
 from sphinx.util.compat import Directive
 import tinkerer
+from tinkerer.ext.uistr import UIStr
+from tinkerer.utils import name_from_title
 
 
 
@@ -33,6 +35,7 @@ class Metadata:
         Initializes metadata with default values.
         '''
         self.is_post = False
+        self.is_page = False
         self.title = None
         self.link = None
         self.date = None
@@ -41,7 +44,7 @@ class Metadata:
         self.filing = { "tags": [], "categories": [] }
         self.comments, self.comment_count = False, False
 
-               
+
 
 class CommentsDirective(Directive):
     '''
@@ -74,6 +77,11 @@ def get_metadata(app, docname):
     env.blog_metadata[docname] = Metadata()
     metadata = env.blog_metadata[docname]
 
+    # if it's a page
+    if docname.startswith("pages/"):
+      metadata.is_page = True
+      return
+
     # posts are identified by ($YEAR)/($MONTH)/($DAY) paths
     match = re.match(r"\d{4}/\d{2}/\d{2}/", docname)
 
@@ -89,7 +97,7 @@ def get_metadata(app, docname):
 
 def process_metadata(app, env):
     '''
-    Processes metadata after all sources are read - the function determines 
+    Processes metadata after all sources are read - the function determines
     post and page ordering, stores doc titles and adds "Home" link to page
     list.
     '''
@@ -113,10 +121,10 @@ def process_metadata(app, env):
             if relations[doc][0] == tinkerer.master_doc:
                 if env.blog_metadata[doc].is_post:
                     env.blog_posts.append(doc)
-                else:
+                elif env.blog_metadata[doc].is_page:
                     env.blog_pages.append(doc)
-     
-    env.blog_page_list = [("index", _("Home"))] + [(page, env.titles[page].astext()) for page in env.blog_pages]
+
+    env.blog_page_list = [("index", UIStr.HOME)] + [(page, env.titles[page].astext()) for page in env.blog_pages]
 
 
 
@@ -129,18 +137,35 @@ def add_metadata(app, pagename, context):
     # blog tagline and pages
     context["tagline"] = app.config.tagline
     context["pages"] = env.blog_page_list
-    
+
     # set translation context variables
-    context["text_recent_posts"] = _("Recent Posts")
-    context["text_posted_by"] = _("Posted by")
-    context["text_blog_archive"] = _("Blog Archive")
-    context["text_filed_under"] = _("Filed under")
-    context["text_tags"] = _("Tags")
-    context["timestamp_format"] = _('%B %d, %Y')    
+    context["text_recent_posts"] = UIStr.RECENT_POSTS
+    context["text_posted_by"] = UIStr.POSTED_BY
+    context["text_blog_archive"] = UIStr.BLOG_ARCHIVE
+    context["text_filed_under"] = UIStr.FILED_UNDER
+    context["text_tags"] = UIStr.TAGS
+    context["text_tags_cloud"] = UIStr.TAGS_CLOUD
+    context["text_categories"] = UIStr.CATEGORIES
+    context["timestamp_format"] = UIStr.TIMESTAMP_FMT
 
     # recent posts
-    context["recent"] = [(post, env.titles[post].astext()) for post 
+    context["recent"] = [(post, env.titles[post].astext()) for post
             in env.blog_posts[:20]]
+    # tags & categories
+    tags = dict((t, 0) for t in env.filing["tags"])
+    taglinks = dict((t, name_from_title(t)) for t in env.filing["tags"])
+    categories = dict((c, 0) for c in env.filing["categories"])
+    catlinks = dict([(c, name_from_title(c)) for c in env.filing["categories"]])
+    for post in env.blog_posts:
+        p = env.blog_metadata[post]
+        for tag in p.filing["tags"]:
+            tags[tag[1]] += 1
+        for cat in p.filing["categories"]:
+            categories[cat[1]] += 1
+    context["tags"] = tags
+    context["taglinks"] = taglinks
+    context["categories"] = categories
+    context["catlinks"] = catlinks
 
     # if there is metadata for the page, it is not an auto-generated one
     if pagename in env.blog_metadata:
@@ -164,4 +189,3 @@ def add_metadata(app, pagename, context):
     # otherwise provide default metadata
     else:
         context["metadata"] = Metadata()
-
