@@ -42,16 +42,16 @@ def generate_feed(app):
 
         timestamp = email.utils.formatdate(
                 time.mktime(env.blog_metadata[post].date.timetuple()),
-                usegmt=True)
+                localtime=True)
 
         categories = [category[1] for category in env.blog_metadata[post].filing["categories"]]
 
         context["items"].append({
                     "title": env.titles[post].astext(),
                     "link": link,
-                    "description": patch.patch_links(
+                    "description": patch.strip_xml_declaration(patch.patch_links(
                             env.blog_metadata[post].body, 
-                            app.config.website + post[:11]),
+                            app.config.website + post[:11])),
                     "categories": categories,
                     "pubDate": timestamp
                 })
